# Copyright (C) 2011-2012  Patrick Totzke <patricktotzke@gmail.com>
# This file is released under the GNU GPL, version 3 or a later revision.
# For further details see the COPYING file
from .thread import Thread
from .message import Message



from importlib.metadata import version, PackageNotFoundError
from typing import Optional

# this requires python >=3.8
__version__: Optional[str]
try:
    __version__ = version("alot")
except PackageNotFoundError:
    # package is not installed
    __version__ = None


__productname__ = 'alot'
# -__copyright__ = "Copyright (C) 2012-21 Patrick Totzke"
# __author__ = "Patrick Totzke"
# __author_email__ = "patricktotzke@gmail.com"
__description__ = "Terminal MUA using notmuch mail"
# __url__ = "https://github.com/pazz/alot"
# __license__ = "Licensed under the GNU GPL v3+."
